# Changelog

<!--next-version-placeholder-->

## v0.6.0 (2021-04-06)
### Feature
* Disable all line-wrapping ([`501524a`](https://github.com/kalekundert/tidyexc/commit/501524ad0062cf96ac78bd756e3c23eaf6954ccc))

### Documentation
* Improve error message ([`530341f`](https://github.com/kalekundert/tidyexc/commit/530341fe16be5b0892526c9721fe263f3fe6f903))

## v0.5.1 (2020-12-07)
### Fix
* Replace dotmap with a non-recursive alternative ([`293e71c`](https://github.com/kalekundert/tidyexc/commit/293e71c4b06877792ebe7879abf3897f2d913550))

## v0.5.0 (2020-12-03)
### Feature
* Respect explicit line breaks in error messages ([`14a698e`](https://github.com/kalekundert/tidyexc/commit/14a698e09009dde3c2aaa058f99f9e9f9d7ea2b9))

## v0.4.0 (2020-12-03)
### Feature
* Allow __iadd__ to work with sequences or scalars ([`89dbe1e`](https://github.com/kalekundert/tidyexc/commit/89dbe1edf096a8bb5f942927151192e0d75fefa5))

### Documentation
* Mention semantic versioning ([`fdd2797`](https://github.com/kalekundert/tidyexc/commit/fdd27970da9ec0a9bcce5b8ad9818b6a82d1e98a))

## v0.3.0 (2020-12-02)
### Feature
* Avoid line-wrapping paths ([`65c0149`](https://github.com/kalekundert/tidyexc/commit/65c014999026b95c12f0d30665f2d9a8c54ad4c0))

### Documentation
* Write documentation ([`04b79f7`](https://github.com/kalekundert/tidyexc/commit/04b79f7bfa7238ddbf18f357475b9f4897a0696a))

## v0.2.0 (2020-11-30)
### Feature
* Make the stack functions class methods ([`bf93c60`](https://github.com/kalekundert/tidyexc/commit/bf93c6084c3f33895cc2b28e1ef17c7c3fce0e18))
